import Link from "next/link"
import { chapters } from "@/data/chapters"
import { notFound } from "next/navigation"
import { ArrowLeft, BookOpen, FileText, ChevronLeft, ChevronRight } from "lucide-react"
import { getLessonContent } from "@/services/lesson-service"

export default async function LessonPage({
  params,
}: {
  params: { slug: string; lesson: string }
}) {
  console.log("Paramètres de l'URL:", params)

  // Update the slug normalization to better handle special characters
  const normalizedSlug = decodeURIComponent(params.slug).toLowerCase()
  const normalizedLesson = decodeURIComponent(params.lesson).toLowerCase()

  console.log("Normalized slug:", normalizedSlug)
  console.log("Normalized lesson:", normalizedLesson)

  // Find the chapter by comparing normalized slugs
  const chapter = chapters.find((c) => {
    const chapterTitle = c.chapter.split(". ")[1]
    const chapterSlug = chapterTitle
      .toLowerCase()
      .replace(/&/g, "et")
      .replace(/'/g, "-")
      .replace(/\s+/g, "-")
      .normalize("NFD")
      .replace(/[\u0300-\u036f]/g, "")
      .replace(/-+/g, "-")

    console.log(`Chapter "${chapterTitle}" -> normalized slug: "${chapterSlug}"`)

    // Special case for "S'arrêter et stationner" chapter
    if (
      normalizedSlug === "sarreter-et-stationner" &&
      (chapterSlug === "sarreter-et-stationner" || c.chapter.includes("S'arrêter et stationner"))
    ) {
      return true
    }

    // Special case for "Accident & sécurité" chapter
    if (
      normalizedSlug === "accident-et-securite" &&
      (chapterSlug === "accident-et-securite" || c.chapter.includes("Accident & sécurité"))
    ) {
      return true
    }

    return chapterSlug === normalizedSlug
  })

  if (!chapter) {
    console.log("Chapitre non trouvé:", normalizedSlug)
    console.log(
      "Chapitres disponibles:",
      chapters.map((c) => {
        const title = c.chapter.split(". ")[1]
        return {
          title,
          slug: title
            .toLowerCase()
            .replace(/&/g, "et")
            .replace(/'/g, "-")
            .replace(/\s+/g, "-")
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "")
            .replace(/-+/g, "-"),
        }
      }),
    )
    return notFound()
  }

  // Find the lesson by comparing normalized titles
  const lessonIndex =
    chapter?.lessons.findIndex((l) => {
      const lessonTitle = l.title
      const lessonSlug = lessonTitle
        .toLowerCase()
        .replace(/&/g, "et")
        .replace(/'/g, "-")
        .replace(/\s+/g, "-")
        .normalize("NFD")
        .replace(/[\u0300-\u036f]/g, "")
        .replace(/-+/g, "-")

      console.log(`Lesson "${lessonTitle}" -> normalized slug: "${lessonSlug}"`)

      // Special case for "S'arrêter et stationner" lesson
      if (
        normalizedLesson === "sarreter-et-stationner" &&
        (lessonSlug === "sarreter-et-stationner" || l.title.includes("S'arrêter et stationner"))
      ) {
        return true
      }

      return lessonSlug === normalizedLesson
    }) ?? -1

  console.log("Recherche de la leçon:", normalizedLesson)
  console.log("Index de la leçon trouvé:", lessonIndex)

  const lesson = chapter.lessons[lessonIndex]
  const prevLesson = lessonIndex > 0 ? chapter.lessons[lessonIndex - 1] : null
  const nextLesson = lessonIndex < chapter.lessons.length - 1 ? chapter.lessons[lessonIndex + 1] : null

  // Récupérer le contenu de la leçon depuis le fichier HTML
  const lessonContent = await getLessonContent(normalizedSlug, normalizedLesson)
  console.log("Contenu de la leçon récupéré:", lessonContent ? "Oui" : "Non")

  return (
    <div className="min-h-screen bg-gray-50">
      <div className={`py-12 px-4 ${chapter.color || "bg-blue-100"}`}>
        <div className="container mx-auto">
          <div className="flex justify-between items-center mb-6">
            <Link href={`/chapitres/${params.slug}`} className="flex items-center text-gray-700 hover:underline">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Retour au chapitre
            </Link>

            <div className="text-sm text-gray-600">
              Leçon {lessonIndex + 1} sur {chapter.lessons.length}
            </div>
          </div>

          <h1 className="text-3xl font-bold text-gray-900 mb-2">{lesson.title}</h1>
          <p className="text-xl text-gray-800">{lesson.description}</p>
        </div>
      </div>

      <div className="container mx-auto py-8 px-4">
        <div className="bg-white rounded-lg shadow-lg overflow-hidden">
          <div className="p-8">
            {lessonContent ? (
              <div className="prose prose-lg max-w-none" dangerouslySetInnerHTML={{ __html: lessonContent.html }} />
            ) : (
              <div className="text-center py-8">
                <p className="text-gray-500 mb-4">Le contenu de cette leçon n'est pas disponible.</p>
                <p className="text-sm text-gray-400">
                  Vérifiez que le fichier <code>{normalizedLesson}.html</code> existe dans le dossier{" "}
                  <code>data/lessons/{normalizedSlug}/</code>
                </p>
              </div>
            )}
          </div>
        </div>

        <div className="mt-8 flex justify-between">
          {prevLesson ? (
            <Link
              href={prevLesson.link}
              className="bg-gray-200 hover:bg-gray-300 text-gray-800 py-2 px-6 rounded-lg flex items-center"
            >
              <ChevronLeft className="mr-2 h-4 w-4" />
              {prevLesson.title}
            </Link>
          ) : (
            <Link
              href={`/chapitres/${params.slug}`}
              className="bg-gray-200 hover:bg-gray-300 text-gray-800 py-2 px-6 rounded-lg flex items-center"
            >
              <BookOpen className="mr-2 h-4 w-4" />
              Toutes les leçons
            </Link>
          )}

          {lesson.Exercice ? (
            <Link
              href={`/exercices/${lesson.Exercice}`}
              className="bg-green-600 hover:bg-green-700 text-white py-2 px-6 rounded-lg flex items-center"
            >
              <FileText className="mr-2 h-4 w-4" />
              Faire l'exercice
            </Link>
          ) : nextLesson ? (
            <Link
              href={nextLesson.link}
              className="bg-blue-600 hover:bg-blue-700 text-white py-2 px-6 rounded-lg flex items-center"
            >
              {nextLesson.title}
              <ChevronRight className="ml-2 h-4 w-4" />
            </Link>
          ) : (
            <Link
              href={`/chapitres/${params.slug}/exercices`}
              className="bg-green-600 hover:bg-green-700 text-white py-2 px-6 rounded-lg flex items-center"
            >
              <FileText className="mr-2 h-4 w-4" />
              Tous les exercices
            </Link>
          )}
        </div>
      </div>
    </div>
  )
}
